@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0037';
+our $VERSION = '0.0038';
 
 use Moo;
 use strictures 2;
@@ -122,7 +122,7 @@ sub search_settings {
   my $sql = q/select id,name,settings,json_extract(settings, '$.group') as mygroup, json_extract(settings, '$.parameter') as parameter from /
     . $self->model
     . ' where ' . join(' and ', @where)
-    . ' order by mygroup,parameter';
+    . ' order by name,mygroup,parameter';
   print "Search SQL: $sql\n" if $self->verbose;
   my $results = $self->_sqlite->query($sql);
   my @settings;
@@ -221,7 +221,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0037
+version 0.0038
 
 =head1 SYNOPSIS
 
